@@ -7,7 +7,7 @@ from typing import Tuple, TypedDict, Any, Optional, Annotated
 from langchain_core.messages import AnyMessage
 from langgraph.graph import add_messages
 
-from ...runtime.langchain.constants import ELITEA_RS
+from ...runtime.langchain.constants import ELITEA_RS, PRINTER_NODE_RS
 
 logger = logging.getLogger(__name__)
 
@@ -131,13 +131,15 @@ def parse_type(type_str):
 
 
 def create_state(data: Optional[dict] = None):
-    state_dict = {'input': str, 'router_output': str, ELITEA_RS: str}  # Always include router_output
+    state_dict = {'input': str, 'router_output': str,
+                  ELITEA_RS: str, PRINTER_NODE_RS: str}  # Always include router_output
     types_dict = {}
     if not data:
         data = {'messages': 'list[str]'}
     for key, value in data.items():
         # support of old & new UI
         value = value['type'] if isinstance(value, dict) else value
+        value = 'str' if value == 'string' else value  # normalize string type (old state support)
         if key == 'messages':
             state_dict[key] = Annotated[list[AnyMessage], add_messages]
         elif value in ['str', 'int', 'float', 'bool', 'list', 'dict', 'number', 'dict']:
@@ -184,7 +186,7 @@ def propagate_the_input_mapping(input_mapping: dict[str, dict], input_variables:
                 logger.error(f"KeyError in fstring formatting for key '{key}'. Attempt to find proper data in state.\n{e}")
                 try:
                     # search for variables in state if not found in var_dict
-                    input_data[key] = value['value'].format(**state)
+                    input_data[key] = safe_format(value['value'], state)
                 except KeyError as no_var_exception:
                     logger.error(f"KeyError in fstring formatting for key '{key}' with state data.\n{no_var_exception}")
                     # leave value as is if still not found (could be a constant string marked as fstring by mistake)
@@ -195,6 +197,13 @@ def propagate_the_input_mapping(input_mapping: dict[str, dict], input_variables:
             input_data[key] = source.get(value['value'], "")
     return input_data
 
+def safe_format(template, mapping):
+    """Format a template string using a mapping, leaving placeholders unchanged if keys are missing."""
+
+    def replacer(match):
+        key = match.group(1)
+        return str(mapping.get(key, f'{{{key}}}'))
+    return re.sub(r'\{(\w+)\}', replacer, template)
 
 def create_pydantic_model(model_name: str, variables: dict[str, dict]):
     fields = {}
